use crate::dom::element::Element;

macro_rules! create_datatype {
    ($($i: ident),+) => {
        #[allow(non_camel_case_types)]
        #[derive(Debug, Clone)]
        pub enum DataType {
            $($i($i),)*
        }
        impl ToString for DataType {
            fn to_string(&self) -> String {
                match self {
                    $(
                        DataType::$i(v) => v.to_string(),
                    )*
                }
            }
        }
        $(
            impl Into<DataType> for $i {
                fn into(self) -> DataType {
                    DataType::$i(self)
                }
            }
        )*
    };
}

create_datatype!(String, Element, i32);

impl Into<DataType> for &str {
    fn into(self) -> DataType {
        DataType::String(self.to_string())
    }
}

impl Into<DataType> for &mut Element {
    fn into(self) -> DataType {
        DataType::Element(self.clone())
    }
}
