use std::fs::File;
use std::io::Error;
use std::path::{Path, PathBuf};

pub trait Fileify {
    fn get_file(&self) -> Result<File, Error>;

    fn ensure_file(&self) -> Result<File, Error>;
}

impl Fileify for Path {
    fn get_file(&self) -> Result<File, Error> {
        self.to_path_buf().get_file()
    }

    fn ensure_file(&self) -> Result<File, Error> {
        self.to_path_buf().ensure_file()
    }
}

impl Fileify for PathBuf {
    fn get_file(&self) -> Result<File, Error> {
        File::open(self)
    }

    fn ensure_file(&self) -> Result<File, Error> {
        let mut f: std::io::Result<File> = File::open(self);
        if let Err(_) = f {
            f = File::create(self);
        }
        f
    }
}